#!/bin/bash
# packager           : Fred. Galusik <fredg> (fredgk~AT~gmail.com)
# source location    : http://nostatic.org/grip/
# last revised       : 27/03/07

softname='grip'
softversion='3.3.1'
packageversion='46.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: gtk2+ CD player and ripper
$softname:
$softname: Grip is a cd-player and cd-ripper for the Gnome desktop.
$softname: It has the ripping capabilities of cdparanoia builtin,
$softname: but can also use external rippers (such as cdda2wav).
$softname: It also provides an automated frontend for MP3
$softname: (and other audio format) encoders.
$softname: Internet disc lookups are supported for retrieving track
$softname: information from disc database servers.
$softname:
$softname:
EOF

# extract the source code
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar zxvf $srcpkg
cd $src

# configure package for compilation and install it to the target directory
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --enable-static=no \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux
           
    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS AUTHORS COPYING CREDITS ChangeLog INSTALL NEWS README TODO \
      $dest/usr/doc/$softname-$softversion
      
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Grip
Name[ca]=Grip
Name[es]=Grip
Name[de]=Grip
Name[fi]=Grip
Name[zh_CN]=Grip MP3 å<88>¶äœ<9C>çš<8B>åº<8F>
Name[zh_CN.GB2312]=Grip MP3 å<88>¶äœ<9C>çš<8B>åº<8F>
Name[zh_TW]=Grip MP3 è£œäœ<9C>çš<8B>åŒ<8F>
Name[zh_TW.Big5]=Grip MP3 è£œäœ<9C>çš<8B>åŒ<8F>
Comment=CD player/ripper
Comment[ca]=Reproductor/extractor de CD d'audio
Comment[es]=Reproductor/extractor de CDs de audio
Comment[de]=Audio-CDs rippen und MP3s/OGGs kodieren
Comment[fr]=Lecteur/extracteur de CD audio
Comment[fi]=CD-audion soitto- ja kopiointiohjelma
Comment[zh_CN]=Grip è®©æ<82>šèœ»æ<9D>Ÿå<88>¶äœ<9C> MP3 æ<96><87>ä»¶
Comment[zh_CN.GB2312]=Grip è®©æ<82>šèœ»æ<9D>Ÿå<88>¶äœ<9C> MP3 æ<96><87>ä»¶
Comment[zh_TW]=Grip è®<93>æ<82>šèŒ<95>é¬<86>è£œäœ<9C> MP3 æª<94>
Comment[zh_TW.Big5]=Grip è®<93>æ<82>šèŒ<95>é¬<86>è£œäœ<9C> MP3 æª<94>
Exec=grip
Icon=gripicon
Type=Application
Categories=Application;AudioVideo;
EOF

# Make the package freedesktop compliant
cp $dest/usr/share/pixmaps/gripicon.png $dest/usr/share/icons/hicolor/48x48/apps/gripicon.png

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
